==> metasploit-framework_4.16.32.orig.tar.gz: metasploit-framework-4.16.32/spec/file_fixtures/modules/exploits/single_target_exploit.rb <==
require 'msf/core'

class MetasploitModule < Msf::Exploit::Remote
  include Exploit::Remote::Tcp

  Rank = ManualRanking

  def initialize(info = {})
    super(update_info(info,
                      'Name'           => 'Exploit With a Single Target',
                      'Description'    => %q{ This module is a test bed for automatic targeting when there is only one target. },
                      'Author'         => [ 'thelightcosine' ],
                      'License'        => MSF_LICENSE,
                      'Privileged'     => true,
                      'DefaultOptions' =>
                        {
                          'WfsDelay'     => 10,
                          'EXITFUNC' => 'thread'
                        },
                      'Payload'        =>
                        {
                          'Space'        => 3072,
                          'DisableNops'  => true
                        },
                      'Platform'       => 'win',
                      'Arch'           => [ARCH_X86, ARCH_X64],
                      'Targets'        =>
                        [
                          ['Windows 2000 Universal',
                           {
                             'Ret'       => 0x001f1cb0,
                             'Scratch'   => 0x00020408,
                           }
                          ], # JMP EDI SVCHOST.EXE
                        ],
                      'DisclosureDate' => 'Jan 01 1999'
          ))
  end

  def exploit
    print_status("This exploit doesn't actually do anything")
  end


end

==> metasploit-framework_6.1.27.orig.tar.gz: metasploit-framework-6.1.27/spec/file_fixtures/modules/exploits/single_target_exploit.rb <==

class MetasploitModule < Msf::Exploit::Remote
  include Exploit::Remote::Tcp

  Rank = ManualRanking

  def initialize(info = {})
    super(update_info(info,
                      'Name'           => 'Exploit With a Single Target',
                      'Description'    => %q{ This module is a test bed for automatic targeting when there is only one target. },
                      'Author'         => [ 'thelightcosine' ],
                      'License'        => MSF_LICENSE,
                      'Privileged'     => true,
                      'DefaultOptions' =>
                        {
                          'WfsDelay'     => 10,
                          'EXITFUNC' => 'thread'
                        },
                      'Payload'        =>
                        {
                          'Space'        => 3072,
                          'DisableNops'  => true
                        },
                      'Platform'       => 'win',
                      'Arch'           => [ARCH_X86, ARCH_X64],
                      'Targets'        =>
                        [
                          ['Windows 2000 Universal',
                           {
                             'Ret'       => 0x001f1cb0,
                             'Scratch'   => 0x00020408,
                           }
                          ], # JMP EDI SVCHOST.EXE
                        ],
                      'DisclosureDate' => '1999-01-01'
          ))
  end

  def exploit
    print_status("This exploit doesn't actually do anything")
  end


end
